@@ -3,10 +3,14 @@
 http://code.google.com/p/django-values/
 """
 from decimal import Decimal
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
+
 from django import forms
 from django.core.exceptions import ImproperlyConfigured
 from django.db import connection, DatabaseError
-from django.utils import simplejson
 from django.utils.datastructures import SortedDict
 from django.utils.encoding import smart_str
 from django.utils.safestring import mark_safe
@@ -224,7 +228,7 @@ class Value(object):
                 work = []
                 for x in self.choices:
                     if x[0] in self.default:
-                        work.append(smart_str(x[1]))
+                        work.append('%s' % smart_str(x[1]))
                 note = gettext('Default value: ') + ", ".join(work)
 
             else:
@@ -574,7 +578,9 @@ class PercentValue(Value):
         else:
             return unicode(value)
 
+
 class PositiveIntegerValue(IntegerValue):
+    """Non negative integer value. (positive or zero)."""
 
     class field(forms.IntegerField):
 
@@ -668,7 +674,7 @@ class MultipleStringValue(Value):
     def get_db_prep_save(self, value):
         if is_string_like(value):
             value = [value]
-        return simplejson.dumps(value)
+        return json.dumps(value)
 
     def to_python(self, value):
         if not value or value == NOTSET:
@@ -677,7 +683,7 @@ class MultipleStringValue(Value):
             return value
         else:
             try:
-                return simplejson.loads(value)
+                return json.loads(value)
             except:
                 if is_string_like(value):
                     return [value]
